!> Module implementing the ITM physics constants
!>
!> Source:
!>  based on SOLPS b2mod_constants.F
!>    '09/12/07 xpb : source CODATA 2006 (http://www.nist.gov/)'
!>  pulled from ets r100
!>
!> \author David Coster
!>
!> \version "$Id: itm_constants.f90 37 2009-08-17 17:15:00Z coster $"

module itm_constants

  use itm_types

  real (kind = R8), parameter :: itm_pi = 3.141592653589793238462643383280_R8
  real (kind = R8), parameter :: itm_c = 2.99792458e8_R8         ! speed of light, m/s
  real (kind = R8), parameter :: itm_me = 9.10938215e-31_R8      ! electron mass, kg
  real (kind = R8), parameter :: itm_mp = 1.672621637e-27_R8     ! proton mass, kg
  real (kind = R8), parameter :: itm_md = 3.34358320e-27_R8      ! deuteron mass, kg
  real (kind = R8), parameter :: itm_mt = 5.00735588e-27_R8      ! triton mass, kg
  real (kind = R8), parameter :: itm_ma = 6.64465620e-27_R8      ! alpha mass, kg
  real (kind = R8), parameter :: itm_amu = 1.660538782e-27_R8    ! amu, kg
  real (kind = R8), parameter :: itm_ev = 1.602176487e-19_R8
  real (kind = R8), parameter :: itm_qe = itm_ev
  real (kind = R8), parameter :: itm_mu0 = 4.0e-7_R8 * itm_pi
  real (kind = R8), parameter :: itm_eps0 = 1.0_R8 / (itm_mu0 * itm_c * itm_c)
  real (kind = R8), parameter :: itm_avogr = 6.02214179e23_R8
  real (kind = R8), parameter :: itm_KBolt = 1.3806504e-23_R8
  character (len=64), parameter :: itm_constants_version = '$Id: itm_constants.f90 37 2009-08-17 17:15:00Z coster $'

end module itm_constants
